'From Squeak3.9alpha of 4 July 2005 [latest update: #7021] on 12 October 2006 at 5:42:31 pm'!
TestCase subclass: #CurlFtpTests
	instanceVariableNames: 'ftpContents'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CurlPlugin'!

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 14:19'!
ftpContents

	^ftpContents ifNil: [String streamContents: [:s |
			0 to: 10000 do: [:i | s nextPutAll: i printString , 'this is a test'; cr ]]].! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 13:11'!
ftpExistingUrl

	^'ftp://127.0.0.1/Upload/tmp/file.dat'! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 13:12'!
ftpLocalWorkDir

	^FileDirectory on: 'c:\Danil\Deploy\Upload\tmp'  ! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 13:11'!
ftpNonExistingUrl

	^'ftp://127.0.0.1/Upload/tmp/nosuchfile.txt'! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 13:11'!
ftpNotWriteableUrl

	^'ftp://127.0.0.1/Upload/tmp/tmp.txt'! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 12:42'!
ftpTestsAreConfigured

	^true! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 15:40'!
ftpWriteablePath

	^'/Upload/tmp/' ! !

!CurlFtpTests methodsFor: 'ftpConfig' stamp: 'dao 10/1/2006 15:38'!
ftpWriteableUrl

	^'ftp://127.0.0.1' , self ftpWriteablePath , 'tmp.txt'! !


!CurlFtpTests methodsFor: 'setup/teardown' stamp: 'dao 10/1/2006 17:00'!
ftpSetUp

	| fStream |
	self ftpTestsAreConfigured ifFalse: [^self].

	self ftpLocalWorkDir deleteLocalFiles.
	fStream := self ftpLocalWorkDir forceNewFileNamed: 
					(self ftpExistingUrl findTokens: '/' ) last.
	fStream nextPutAll: self ftpContents.
	fStream close.! !

!CurlFtpTests methodsFor: 'setup/teardown' stamp: 'dao 10/1/2006 12:59'!
setUp

	super setUp.
	self ftpSetUp.! !

!CurlFtpTests methodsFor: 'setup/teardown' stamp: 'dao 10/1/2006 12:33'!
tearDown

	^super tearDown ! !


!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:07'!
testFtpDownload

	| curl contents |
	self ftpTestsAreConfigured ifFalse: [^self].

	curl := Curl new.
	self 
		shouldnt: [ contents := curl getContentsUrl: self ftpExistingUrl ]  
		raise: Error. 

	self assert: contents = self ftpContents.
	
	self 
		should: [curl getContentsUrl: self ftpNonExistingUrl  ]
		raise: Error.
		

	

! !

!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:06'!
testFtpDownloadInfo

	| curl |
	self ftpTestsAreConfigured ifFalse: [^self].

	"download file"
	curl := Curl new.
	curl onFileTime. " ask servers to tell the time of the files"
	self 
		shouldnt: [ curl getContentsUrl: self ftpExistingUrl ]  
		raise: Error. 

	"< 226 Transfer complete."
	self assert: curl infoResponseCode = 226.
	self assert: curl infoSizeDownload = self ftpContents size.
	self assert: curl infoSpeedDownload > 0.
	self assert: curl infoContentLengthDownload = self ftpContents size.

	self assert: curl infoEffectiveUrl = self ftpExistingUrl.
	self assert: curl infoFtpEntryPath = '/'.
	self assert: curl infoPrivate = ''.
	self assert: curl infoContentType = ''.
	
	curl infoFileTime ifNil: [^self "some servers don't return time of documents - skip checks in this case"].
	self assert: curl infoFileTime <= DateAndTime now.
	self assert: curl infoFileTime >= DateAndTime now - (Duration hours: 1) " running the test should not take that long :) "
	
	

! !

!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:05'!
testFtpDownloadInfoTimings

	| curl |
	self ftpTestsAreConfigured ifFalse: [^self].

	"download file"
	curl := Curl new.
	self 
		shouldnt: [ curl getContentsUrl: self ftpExistingUrl ]  
		raise: Error. 
	
	self assert: curl infoRedirectTime = Duration zero. "no redirect"
	"refer to libcurl man pages for the complete description of time values"
	self assert: curl infoTotalTime >= curl infoStartTransferTime.
	self assert: curl infoStartTransferTime >= curl infoPreTransferTime.
	self assert: curl infoPreTransferTime >= curl infoConnectTime.
	self assert: curl infoConnectTime >= curl infoNameLookupTime.
	self assert: curl infoNameLookupTime >= Duration zero.
	
	
	

! !

!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 13:29'!
testFtpUpload

	| curl |
	self ftpTestsAreConfigured ifFalse: [^self].

	curl := Curl new.
	self 
		shouldnt: [ curl putContents: self ftpContents url: self ftpWriteableUrl ]  
		raise: Error. 
	
	"the second time we can not write the same url - file exists"
	self 
		should: [curl putContents: 'whatever' ]
		raise: Error.
		

	

! !

!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 16:11'!
testFtpUploadInfo

	| curl |
	self ftpTestsAreConfigured ifFalse: [^self].

	"upload file"
	curl := Curl new.
	curl onFileTime. " ask servers to tell the time of the files"
	self 
		shouldnt: [ curl putContents: self ftpContents url: self ftpWriteableUrl ]  
		raise: Error. 

	"< 226 Transfer complete."
	self assert: curl infoResponseCode = 226.
	self assert: curl infoSizeUpload = self ftpContents size.
	self assert: curl infoSpeedUpload > 0.
	self assert: curl infoContentLengthUpload = self ftpContents size.

	self assert: curl infoEffectiveUrl = self ftpWriteableUrl.
	self assert: curl infoFtpEntryPath = '/'.
	self assert: curl infoPrivate = ''.
	self assert: curl infoContentType = ''.
	
	curl infoFileTime ifNil: [^self "some servers don't return time of documents - skip checks in this case"].
	self assert: curl infoFileTime <= DateAndTime now.
	self assert: curl infoFileTime >= DateAndTime now - (Duration hours: 1) " running the test should not take that long :) "
	
	

! !

!CurlFtpTests methodsFor: 'testing' stamp: 'dao 10/1/2006 13:40'!
testFtpUploadInfoTimings

	| curl |
	self ftpTestsAreConfigured ifFalse: [^self].

	"upload file"
	curl := Curl new.
	self 
		shouldnt: [ curl putContents: self ftpContents url: self ftpWriteableUrl ]  
		raise: Error. 
	
	self assert: curl infoRedirectTime = Duration zero. "no redirect"
	"refer to libcurl man pages for the complete description of time values"
	self assert: curl infoTotalTime >= curl infoStartTransferTime.
	self assert: curl infoStartTransferTime >= curl infoPreTransferTime.
	self assert: curl infoPreTransferTime >= curl infoConnectTime.
	self assert: curl infoConnectTime >= curl infoNameLookupTime.
	self assert: curl infoNameLookupTime >= Duration zero.
	
	
	

! !
