'From Squeak3.9alpha of 4 July 2005 [latest update: #7021] on 12 October 2006 at 5:46:47 pm'!
TestCase subclass: #CurlTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CurlPlugin'!

!CurlTests methodsFor: 'setup/teardown' stamp: 'dao 10/10/2006 18:23'!
setUp

	"force the fresh start for every test"
	SmalltalkImage current unloadModule: 'CurlPlugin'! !


!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 18:27'!
testApiBasic

	"should not fail with good input, should primFail on bad and should not crash, no used memory after destroy"
	| curl |
	curl := Curl new.

	self shouldnt: [curl cancel] raise: Error.
	self assert: curl contents = nil.
	self shouldnt: [curl contents: 'whatever'] raise: Error.
	self should: [curl contents: 123 ] raise: Error.
	self assert: curl contents = 'whatever'.
	self shouldnt: [curl clearContents ] raise: Error.
	self assert: curl contents = nil.

	
	self shouldnt: [curl url: 'whatever'] raise: Error.
	self should: [curl url: 111] raise: Error.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/7/2006 19:59'!
testApiHttpAuthOptions

	"should not fail with good input, should primFail on bad and should not crash, no used memory after destroy"
	| curl |
	curl := Curl new.


	self shouldnt: [curl userPwd: 'whatever'] raise: Error.
	self shouldnt: [curl proxyUserPwd: 'whatever'] raise: Error.

	self shouldnt: [curl onHttpAuthBasic] raise: Error.
	self shouldnt: [curl onHttpAuthDigest ] raise: Error.
	self shouldnt: [curl onHttpAuthNtlm ] raise: Error.
	self shouldnt: [curl onHttpAuthAny ] raise: Error.
	self shouldnt: [curl onHttpAuthAnySafe ] raise: Error.

	self shouldnt: [curl onProxyAuthBasic] raise: Error.
	self shouldnt: [curl onProxyAuthDigest ] raise: Error.
	self shouldnt: [curl onProxyAuthNtlm ] raise: Error.
	self shouldnt: [curl onProxyAuthAny ] raise: Error.
	self shouldnt: [curl onProxyAuthAnySafe ] raise: Error.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/8/2006 18:09'!
testApiHttpOptions

	"should not fail with good input, should primFail on bad and should not crash, no used memory after destroy"
	| curl |
	curl := Curl new.

	self shouldnt: [curl onAutoReferer ] raise: Error.
	self shouldnt: [curl onFollowLocation ] raise: Error.
	self shouldnt: [curl onGetHeader ] raise: Error.
	self shouldnt: [curl onHttpGet] raise: Error.
	self shouldnt: [curl onUnrestrictedAuth ] raise: Error.
	self shouldnt: [curl onPost ] raise: Error.
	self shouldnt: [curl maxRedirs: 5 ] raise: Error.
	self shouldnt: [curl cookieSession ] raise: Error.
	self shouldnt: [curl cookie: '' ] raise: Error.
	self shouldnt: [curl cookieFile: 'cookies.txt' ] raise: Error.
	self shouldnt: [curl cookieJar: 'cookies.jar' ] raise: Error.

	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 18:44'!
testApiInfoStrings

	"all this should be set to zero before the transfer for new handle"
	| curl |
	curl := Curl new.

	self assert:  curl infoContentType = ''.
	self assert:  curl infoEffectiveUrl = ''.
	self assert:  curl infoFtpEntryPath = ''.
	self assert:  curl infoPrivate = ''.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/7/2006 19:48'!
testApiOptions

	"should not fail with good input, should primFail on bad and should not crash, no used memory after destroy"
	| curl |
	curl := Curl new.

	self shouldnt: [curl caInfo: 'whatever'] raise: Error.
	self shouldnt: [curl proxy: 'whatever'] raise: Error.
	self shouldnt: [curl timeout: 1 ] raise: Error.
	self shouldnt: [curl userPwd: 'whatever'] raise: Error.
	self shouldnt: [curl proxyUserPwd: 'whatever'] raise: Error.
	self shouldnt: [curl url: 'whatever'] raise: Error.

	self should: [curl caInfo: nil] raise: Error.
	self should: [curl proxy: 666 ] raise: Error.
	self should: [curl timeout: 'Wait long ' ] raise: Error.
	self should: [curl timeout: 10000000 ] raise: Error.
	self should: [curl userPwd: false ] raise: Error.
	self should: [curl url: self] raise: Error.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/7/2006 20:51'!
testApiSwitches

	"should not fail "
	| curl |
	curl := Curl new.

	self shouldnt: [ curl onFailOnError ] raise: Error.
	self shouldnt: [ curl onFileTime ] raise: Error.
	self shouldnt: [ curl onGetHeader ] raise: Error.
	self shouldnt: [ curl onSSLVerifyPeer ] raise: Error.
	self shouldnt: [ curl onUpload ] raise: Error.
	self shouldnt: [ curl onVerbose ] raise: Error.
	self shouldnt: [ curl onFollowLocation ] raise: Error.
	self shouldnt: [ curl onUnrestrictedAuth ] raise: Error.
	self shouldnt: [ curl onHttpProxyTunnel  ] raise: Error.

	self shouldnt: [ curl offFailOnError ] raise: Error.
	self shouldnt: [ curl offFileTime ] raise: Error.
	self shouldnt: [ curl offGetHeader ] raise: Error.
	self shouldnt: [ curl offSSLVerifyPeer ] raise: Error.
	self shouldnt: [ curl offUpload ] raise: Error.
	self shouldnt: [ curl offVerbose ] raise: Error.
	self shouldnt: [ curl offFollowLocation ] raise: Error.
	self shouldnt: [ curl offUnrestrictedAuth ] raise: Error.
	self shouldnt: [ curl onHttpProxyTunnel  ] raise: Error.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 18:42'!
testApiTimings

	"all this should be set to zero before the transfer - please, dont crash :)"
	| curl |
	curl := Curl new.

	self assert:  curl infoConnectTime = Duration zero.
	self assert:  curl infoNameLookupTime = Duration zero.
	self assert:  curl infoPreTransferTime = Duration zero.
	self assert:  curl infoRedirectTime = Duration zero.
	self assert:  curl infoStartTransferTime = Duration zero.
	self assert:  curl infoTotalTime = Duration zero.


	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 18:49'!
testApiTransfersParameters

	"all this should be set to zero before the transfer for new handle"
	| curl |
	curl := Curl new.

	self assert:  curl infoContentLengthDownload = 0.
	self assert:  curl infoContentLengthUpload = 0.
	self assert:  curl infoFileTime = (DateAndTime year: 1970 day: 1).
	self assert:  curl infoResponseCode = 0.
	self assert:  curl infoSizeDownload = 0.
	self assert:  curl infoSizeUpload = 0.
	self assert:  curl infoSpeedDownload = 0.
	self assert:  curl infoSpeedUpload = 0.

	curl destroy.
	self assert: Curl pNumberOfMemChunks = 0
	
! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:31'!
testInvalidHandleUse

	| curl |
	curl := Curl new.

	self shouldnt: [curl url: 'whatever'] raise: Error.

	curl destroy.
	
	self should: [curl url: 'whatever'] raise: Error "and should not crash :)"! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:32'!
testMassiveCurlHandleCreation

	| curls |
	curls := Array streamContents: [:s | 1000 timesRepeat: [s nextPut: (Curl new url: 'whatever') ]].
	
	curls do: [:c | c destroy].
	curls := nil.
	3 timesRepeat: [Smalltalk garbageCollect].
	self assert: (Curl pNumberOfMemChunks = 0)! !

!CurlTests methodsFor: 'testing' stamp: 'dao 10/1/2006 17:21'!
testNumberOfMemoryChunks

	self assert: Curl pNumberOfMemChunks = 0! !
